@Echo Off
Rem *****************************************************************************
Rem   Version-checkable upgrade for Service Profiler
Rem *****************************************************************************
Rem   Wrightia, S.A. (c) 2006-2016
Rem
Rem   Purpose:
Rem      If version does not match:
Rem         1. Replace all native libraries
Rem         2. Replace all server and static JAR libraries
Rem
Rem   Input parameters:
Rem      %1  : IS_DIR  (The Integration Server installation directory)
Rem
Rem   Results:
Rem      1. Applies Patch #1 for Service Profiler v1.3.
Rem
Rem   Exit codes:
Rem      0  - OK
Rem
Rem *****************************************************************************

SetLocal
PushD

Set xLogFile=upgrade.log
date /T >> %xLogFile%
time /T >> %xLogFile%

Set xISHome=%~1
Set xSourceHome=..\serviceprofiler
Set xTargetHome=%xISHome%\serviceprofiler
Set xVersionID=10.version

If NOT Exist %xTargetHome% (
   Call :logWarning "Directory '%xTargetHome%' was not found: '%0' not applied."
   goto end-of-patch
)

If Exist %xTargetHome%\%xVersionID% (
   Call :logInfo "Directory '%xTargetHome%' is up to date."
   goto end-of-patch
)

Rem replace static library in package
Call :log "Replacing package-static Java libraries"
XCopy /E /C /I /Y .\static\*.jar ..\..\code\jars\static\*.jar >> %xLogFile%
If NOT ERRORLEVEL 0 (
   Exit /b %ERRORLEVEL%
)

Rem replace previous installation on server folder
RmDir /Q /S %xTargetHome%
Call :log "Copying %xSourceHome%"
MkDir "%xTargetHome%"
XCopy /E /C /I %xSourceHome% "%xTargetHome%" >> %xLogFile%
If NOT ERRORLEVEL 0 (
   Exit /b %ERRORLEVEL%
)

:end-of-patch

PopD
EndLocal

Exit /b 0

:log
   echo %~1 >> %xLogFile%
   Goto :EOF

:logError
   Call :log "ERROR %~1"
   Goto :EOF

:logWarning
   Call :log "WARNING %~1"
   Goto :EOF

:logInfo
   Call :log "INFO %~1"
   Goto :EOF
