#!/bin/sh
# *****************************************************************************
#  Version-checkable upgrade for Service Profiler
# *****************************************************************************
#  Wrightia, S.A. (c) 2006-2016
#
#  Purpose:
#     If version does not match:
#        1. Replace all native libraries
#        2. Replace all server and static JAR libraries
#
#  Input parameters:
#     $1          : IS_DIR  (The Integration Server installation directory)
#
#  Results:
#     1.  Applies Patch #1 for Service Profiler v1.3.
#
#  Exit codes:
#     0  - OK
#
# *****************************************************************************

log() {
   echo "[$1] [`date +%C%y-%m-%d\ %H:%M:%S`] $2" >> upgrade.log
}

logError() {
   log "ERROR" "$1"
}

logWarning() {
   log "WARNING" "$1"
}

logInfo() {
   log "INFO" "$1"
}

#--< MAIN	>------------------------------------------------------------------
xISHome=$1
xTargetHome=$xISHome/serviceprofiler
xVersionID=10.version

if [ -d "$xTargetHome" ] ; then
   if [ ! -f "${xTargetHome}/${xVersionID}" ] ; then

      # replace static library in package
      logInfo "Replacing package-static Java libraries"
      cp -f ./static/*.jar ../../code/jars/static/
      xEL=$?
      if [ $xEL -eq 0 ]; then
         logInfo "package-static jars copied successfully."

         # replace previous installation on server folder
         logInfo "Copying '${xISHome}/serviceprofiler'"
         rm -rf "$xTargetHome"
         cp -r ../serviceprofiler "${xISHome}/"
         xEL=$?
         if [ $xEL -eq 0 ]; then
            logInfo "All files copied successfully."
         else
            logError "Error '$xEL' copying files."
            exit $xEL
         fi
      else
         logError "Error '$xEL' copying libraries."
         exit $xEL
      fi
   else
      logInfo "Directory '$xTargetHome' is up to date."
   fi
else
   logWarning "Directory '$xTargetHome' was not found: '$0 $*' not applied."
fi
